System vars. Some can be dynamically rebound to change system behavior.
System vars. Some can be dynamically rebound to change system behavior.
The number of samples considered when build the key compression dictionary is 65536
The number of samples considered when build the key compression dictionary is 65536
set of additional serializable classes, e.g.
#{"my.package.*"}
set of additional serializable classes, e.g.
`#{"my.package.*"}`Datalog DB starts background sampling or not
Datalog DB starts background sampling or not
The set of English punctuation characters, a Java HashSet. Used in English analyzer.
The set of English punctuation characters, a Java HashSet. Used in English analyzer.
The set of English stop words, a Java HashSet, contains the same words as that of Lucene. Used in English analyzer.
The set of English stop words, a Java HashSet, contains the same words as that of Lucene. Used in English analyzer.
Batch size (# of datoms) when filling Datalog DB
Batch size (# of datoms) when filling Datalog DB
batch size when using search index writer and :index-position? is false
batch size when using search index writer and `:index-position?` is `false`
batch size when using search index writer and :index-position? is true
batch size when using search index writer and `:index-position?` is `true`
Initial db file size is 1000 MiB, automatically grown
Initial db file size is 1000 MiB, automatically grown
Initial maximal value size is 16384 bytes, automatically grown
Initial maximal value size is 16384 bytes, automatically grown
Maximum number of sub-databases allowed in a db file
Maximum number of sub-databases allowed in a db file
Default number of readers allowed for a DB file is 256.
Default number of readers allowed for a DB file is 256.
Maximum LMDB key size is 511 bytes
Maximum LMDB key size is 511 bytes
The full text search engine ignores exceedingly long strings. The maximal allowed term length is 128 characters
The full text search engine ignores exceedingly long strings. The maximal allowed term length is 128 characters
Maximum length of a tuple is 255 bytes
Maximum length of a tuple is 255 bytes
dbi name for Datalog AVE index is datalevin/ave
dbi name for Datalog AVE index is `datalevin/ave`
The default client connection pool size is 3
The default client connection pool size is 3
The default connection timeout is 60000ms (1 minute)
The default connection timeout is 60000ms (1 minute)
Default vector index connectivity is 16
Default vector index connectivity is 16
Default LMDB dbi flag is #{:create}. See http://www.lmdb.tech/doc/group__mdb__dbi__open.html for full list of flags
Default LMDB dbi flag is `#{:create}`. See http://www.lmdb.tech/doc/group__mdb__dbi__open.html for full list of flags
default search function :display option value is :refs
default `search` function `:display` option value is `:refs`
Default LMDB env flag is #{:nordahead :notls}. See
datalevin.core/set-env-flags for a full list of flags.
Passed as :flags option value to open-kv function.
Default LMDB env flag is `#{:nordahead :notls}`. See
[[datalevin.core/set-env-flags]] for a full list of flags.
Passed as `:flags` option value to `open-kv` function.Default vector index expansion-add is 128
Default vector index expansion-add is 128
Default vector index expansion-search is 64
Default vector index expansion-search is 64
The server session default idle timeout is 172800000ms (48 hours)
The server session default idle timeout is 172800000ms (48 hours)
Default vector index metric type is :euclidean
Default vector index metric type is :euclidean
Default vector index multi? flag is false
Default vector index multi? flag is false
The server default password is datalevin
The server default password is `datalevin`
The server default port number is 8898
The server default port number is 8898
default search function :proximity-expansion option value is 2
default `search` function `:proximity-expansion` option value is `2`
default search function :proximity-max-dist option value is 45
default `search` function `:proximity-max-dist` option value is `45`
Default LMDB put flag is #{}. See http://www.lmdb.tech/doc/group__mdb__put.html for full list of flags
Default LMDB put flag is `#{}`. See http://www.lmdb.tech/doc/group__mdb__put.html for full list of flags
Default vector index quantization is :float
Default vector index quantization is :float
Default root directory of spilled files is platform dependent. the same as
the value of Java property java.io.tmpdir
Default root directory of spilled files is platform dependent. the same as the value of Java property `java.io.tmpdir`
Default percentage of heap memory (Xmx) is 95, over which spill-to-disk will be triggered
Default percentage of heap memory (Xmx) is 95, over which spill-to-disk will be triggered
default search function :top option value is 10
default `search` function `:top` option value is `10`
The server default username is datalevin
The server default username is `datalevin`
dbi name suffix for search engine documents index is docs
dbi name suffix for search engine documents index is `docs`
dbi name for Datalog EAV index is datalevin/eav
dbi name for Datalog EAV index is `datalevin/eav`
dbi name for Datalog large datoms is datalevin/giants
dbi name for Datalog large datoms is `datalevin/giants`
Size below which the initial plan will execute during planning, above which, the same number of items will be sampled instead
Size below which the initial plan will execute during planning, above which, the same number of items will be sampled instead
dbi name for kv store system information is datalevin/kv-info
dbi name for kv store system information is `datalevin/kv-info`
Time interval between automatic LMDB sync to disk, in seconds, default is 300
Time interval between automatic LMDB sync to disk, in seconds, default is 300
Cost associated with running a filter during scan
Cost associated with running a filter during scan
Cost associated with scanning e based on a
Cost associated with scanning e based on a
Cost associated with merge-scan join
Cost associated with merge-scan join
Cost associated with running a predicate during scan
Cost associated with running a predicate during scan
Cost associated with val-eq-scan join
Cost associated with val-eq-scan join
Cost associated with adding variable during scan
Cost associated with adding variable during scan
Maximum big decimal has value of (2^1015-1) x 10^2147483648
Maximum big decimal has value of `(2^1015-1) x 10^2147483648`
dbi name for Datalog runtime meta information is datalevin/meta
dbi name for Datalog runtime meta information is `datalevin/meta`
Minimum big decimal has value of -2^1015 x 10^2147483648
Minimum big decimal has value of `-2^1015 x 10^2147483648`
dbi name for Datalog options is datalevin/opts
dbi name for Datalog options is `datalevin/opts`
dbi name suffix for search engine positions index is positions
dbi name suffix for search engine positions index is `positions`
The time measure is taken every this step of iterations when counting.
The time measure is taken every this step of iterations when counting.
The time budget allocated for counting av ranges of an attribute, in milliseconds. The counting will stop if it takes longer than this.
The time budget allocated for counting av ranges of an attribute, in milliseconds. The counting will stop if it takes longer than this.
dbi name suffix for search engine raw text is rawtext
dbi name suffix for search engine raw text is `rawtext`
Change ratio of an attribute's values, beyond which re-sampling will be done
Change ratio of an attribute's values, beyond which re-sampling will be done
The time measure is taken every this step of iterations when sampling.
The time measure is taken every this step of iterations when sampling.
Time interval between sample processing, in seconds
Time interval between sample processing, in seconds
The time budget allocated for sampling an attribute, in milliseconds. The sampling will stop if it takes longer than this.
The time budget allocated for sampling an attribute, in milliseconds. The sampling will stop if it takes longer than this.
dbi name for Datalog schema is datalevin/schema
dbi name for Datalog schema is `datalevin/schema`
dbi name suffix for search engine terms index is terms
dbi name suffix for search engine terms index is `terms`
Default dbi name of the spilled db is t
Default dbi name of the spilled db is `t`
dbi name for Datalog VAE index is datalevin/vae
dbi name for Datalog VAE index is `datalevin/vae`
dbi name suffix for vec-ref -> vec-id map is vec-refs
dbi name suffix for vec-ref -> vec-id map is `vec-refs`
File name suffix for vector index is .vid
File name suffix for vector index is `.vid`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |