Built-in predicates or functions for Datalog query, i.e. used in q
Built-in predicates or functions for Datalog query, i.e. used in `q`
Datalevin client to Datalevin server, blocking API, with a connection pool
Datalevin client to Datalevin server, blocking API, with a connection pool
System vars. Some can be dynamically rebound to change system behavior.
System vars. Some can be dynamically rebound to change system behavior.
User facing API for Datalevin library features
User facing API for Datalevin library features
Code interpreter, including functions and macros useful for command line and query/transaction functions.
Code interpreter, including functions and macros useful for command line and query/transaction functions.
Functions and vars to support the dtlv command line tool
Functions and vars to support the `dtlv` command line tool
Some useful utility functions that can be passed as options to search engine to customize search.
Some useful utility functions that can be passed as options to search engine to customize search.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |