Functions and vars to support the dtlv command line tool
Functions and vars to support the `dtlv` command line tool
(copy src-dir dest-dir compact?)Copy a database. src-dir is the source data directory path. dest-dir is
the destination data directory path. Will compact while copying if
compact? is true.
Copy a database. `src-dir` is the source data directory path. `dest-dir` is the destination data directory path. Will compact while copying if `compact?` is true.
(drop dir dbis delete)Drop (when delete is true) or clear (when delete is false) the list of
sub-database(s) named by dbis from the database at the data directory path
dir.
Drop (when `delete` is true) or clear (when `delete` is false) the list of sub-database(s) named by `dbis` from the database at the data directory path `dir`.
(dump src-dir dest-file dbis list? datalog? all?)(dump src-dir dest-file dbis list? datalog? all? nippy?)Dump database content. src-dir is the database directory path.
The content will be written to dest-file if given, or to stdout.
If list? is true, will list the names of the key-value sub-databases only,
not the content.
If datalog? is true, will dump the whole database as a Datalog store,
including the schema and all the datoms. By default, datoms are printed as
strings. If there are unprintable values in DB, set nippy? to true.
If all? is true, will dump raw data of all the key-value sub-databases,
unless datalog? is true.
If no mode or sub-database is specified, dump mode is auto-detected. Datalog databases are dumped as Datalog data plus user key-value sub-databases; pure key-value databases are dumped as raw key-value data.
If nippy? is true, dump is in nippy binary format, and dest-file must be
given.
If dbis is not empty, will dump raw data of only the named key-value sub-databases,
unless datalog? is true.
Dump database content. `src-dir` is the database directory path. The content will be written to `dest-file` if given, or to stdout. If `list?` is true, will list the names of the key-value sub-databases only, not the content. If `datalog?` is true, will dump the whole database as a Datalog store, including the schema and all the datoms. By default, datoms are printed as strings. If there are unprintable values in DB, set `nippy?` to `true`. If `all?` is true, will dump raw data of all the key-value sub-databases, unless `datalog?` is true. If no mode or sub-database is specified, dump mode is auto-detected. Datalog databases are dumped as Datalog data plus user key-value sub-databases; pure key-value databases are dumped as raw key-value data. If `nippy?` is true, dump is in nippy binary format, and `dest-file` must be given. If `dbis` is not empty, will dump raw data of only the named key-value sub-databases, unless `datalog?` is true.
(exec arguments)Execuate code that passed in as a seq of strings.
Execuate code that passed in as a seq of strings.
(load dir src-file dbi datalog?)(load dir src-file dbi datalog? nippy?)Load content into the database at data directory path dir,
from src-file if given, or from stdin.
If datalog? is true, the content are expected to be schema and datoms.
If neither datalog? nor dbi is specified, the input format is auto-detected.
If nippy? is true, load a nippy binary file, src-file must be given.
Will load raw data into the named sub-database dbi if given.
Load content into the database at data directory path `dir`, from `src-file` if given, or from stdin. If `datalog?` is true, the content are expected to be schema and datoms. If neither `datalog?` nor `dbi` is specified, the input format is auto-detected. If `nippy?` is true, load a nippy binary file, `src-file` must be given. Will load raw data into the named sub-database `dbi` if given.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |